# AbdallahPackage
* pip install twine
* pip install setuptools wheel
* pip install tqdm
* python setup.py sdist
* twine upload --repository-url https://upload.pypi.org/legacy/ dist/*

* View at:
    https://pypi.org/project/AbdallahRadwanLib/0.1/

* Install Command :
    pip install AbdallahRadwanLib==0.1